MediaCodecCapability class

A native Android media codec capability reported by the device.

Constructors

MediaCodecCapability({required String name, required bool isEncoder, required List<String> supportedTypes, required bool isHardwareAccelerated, required bool isSoftwareOnly, required bool isVendor, required List<String> supportedVideoTypes, required List<String> supportedAudioTypes})
Creates a media codec capability description.
const
MediaCodecCapability.fromMap(Map<Object?, Object?> map)
Creates a MediaCodecCapability from a map returned by the native platform.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isEncoder bool
Whether this codec encodes media.
final
isHardwareAccelerated bool
Whether Android reports this codec as hardware accelerated.
final
isSoftwareOnly bool
Whether Android reports this codec as software only.
final
isVendor bool
Whether Android reports this codec as vendor provided.
final
name String
The codec name reported by Android.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedAudioTypes List<String>
Supported audio MIME types.
final
supportedTypes List<String>
MIME types supported by this codec.
final
supportedVideoTypes List<String>
Supported video MIME types.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
Converts this codec capability to a map using the native field names.
toString() String
Returns a readable string containing all codec fields.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited