native_lens library

Classes

CameraCapability
A native Android Camera2 capability reported by the device.
CompatibilitySummary
A readable offline compatibility summary for a NativeLens report.
DeviceOrientationInfo
Device orientation information reported by NativeLens.
DisplayInfo
Native Android display information reported by the device.
MediaCodecCapability
A native Android media codec capability reported by the device.
NativeLens
Entry point for reading basic native Android information.
NativeLensDatasetExporter
Small Dart-only exporter for NativeLens dataset rows.
NativeLensDatasetRow
Stable AI- and dataset-friendly row model for NativeLens snapshots.
NativeLensDebug
Utility helpers for debug-only screen trace printing in NativeLens.
NativeLensReport
A single snapshot report made from the existing NativeLens APIs.
NativeLensScreenTrace
A widget wrapper that prints screen debug information during development.
NativeSensor
A native Android sensor reported by the device.
NetworkCapability
Native Android network capability information for the active network.
NetworkSpeedSample
A live app-level network speed sample.
PlatformSummary
Basic information about the Android device running the app.
PowerState
Native Android battery and power state reported by the device.
ScreenDebugInfo
Information used by the NativeLens screen trace debug utility.
SystemFeature
A native Android system feature reported by the device.