NativeLensDatasetExporter class

Small Dart-only exporter for NativeLens dataset rows.

Constructors

NativeLensDatasetExporter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toCsv(List<NativeLensDatasetRow> rows) String
Serializes a list of rows to a CSV string.
toJson(NativeLensDatasetRow row) String
Serializes a single row to a JSON string.
toJsonList(List<NativeLensDatasetRow> rows) String
Serializes a list of rows to a JSON array string.