printScreen static method
Prints the screen debug trace only when assertions are enabled.
Implementation
static void printScreen(ScreenDebugInfo info) {
assert(() {
debugPrint(formatScreenTrace(info));
return true;
}());
}
Prints the screen debug trace only when assertions are enabled.
static void printScreen(ScreenDebugInfo info) {
assert(() {
debugPrint(formatScreenTrace(info));
return true;
}());
}