NativeLensFeature enum

Smart feature categories supported by NativeLens feature intelligence.

Inheritance
Available extensions

Values

liveStreaming → const NativeLensFeature
videoUpload → const NativeLensFeature
faceFilterCamera → const NativeLensFeature
cameraRecording → const NativeLensFeature
backgroundSync → const NativeLensFeature
arExperience → const NativeLensFeature
stepTracking → const NativeLensFeature
compassNavigation → const NativeLensFeature
mediaProcessing → const NativeLensFeature

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NativeLensFeature>
A constant List of the values in this enum, in order of their declaration.