disallowPowerSaveMode property
Whether the feature should avoid running while power saver is enabled.
Implementation
final bool disallowPowerSaveMode;
Whether the feature should avoid running while power saver is enabled.
final bool disallowPowerSaveMode;