deviceOrientationEventChannel property
The event channel used to receive live device orientation updates.
Implementation
@visibleForTesting
final deviceOrientationEventChannel = const EventChannel(
'native_lens/device_orientation',
);
The event channel used to receive live device orientation updates.
@visibleForTesting
final deviceOrientationEventChannel = const EventChannel(
'native_lens/device_orientation',
);