networkCapabilityEventChannel property
The event channel used to receive live Android network capability updates.
Implementation
@visibleForTesting
final networkCapabilityEventChannel = const EventChannel(
'native_lens/network_capability',
);
The event channel used to receive live Android network capability updates.
@visibleForTesting
final networkCapabilityEventChannel = const EventChannel(
'native_lens/network_capability',
);