networkSpeedEventChannel property
The event channel used to receive live app network speed samples.
Implementation
@visibleForTesting
final networkSpeedEventChannel = const EventChannel(
'native_lens/network_speed',
);
The event channel used to receive live app network speed samples.
@visibleForTesting
final networkSpeedEventChannel = const EventChannel(
'native_lens/network_speed',
);