powerStateEventChannel property
The event channel used to receive live power state updates.
Implementation
@visibleForTesting
final powerStateEventChannel = const EventChannel('native_lens/power_state');
The event channel used to receive live power state updates.
@visibleForTesting
final powerStateEventChannel = const EventChannel('native_lens/power_state');