themeModeEventChannel property
The event channel used to receive live native theme mode updates.
Implementation
@visibleForTesting
final themeModeEventChannel = const EventChannel('native_lens/theme_mode');
The event channel used to receive live native theme mode updates.
@visibleForTesting
final themeModeEventChannel = const EventChannel('native_lens/theme_mode');