getDisplayInfo method
Returns native Android display capabilities for the active display.
Implementation
Future<DisplayInfo> getDisplayInfo() {
throw UnimplementedError('getDisplayInfo() has not been implemented.');
}
Returns native Android display capabilities for the active display.
Future<DisplayInfo> getDisplayInfo() {
throw UnimplementedError('getDisplayInfo() has not been implemented.');
}