getMediaCodecs method
Returns native Android media codec capabilities reported by the device.
Implementation
Future<List<MediaCodecCapability>> getMediaCodecs() {
throw UnimplementedError('getMediaCodecs() has not been implemented.');
}
Returns native Android media codec capabilities reported by the device.
Future<List<MediaCodecCapability>> getMediaCodecs() {
throw UnimplementedError('getMediaCodecs() has not been implemented.');
}