getPlatformSummary method
Returns a summary of the Android platform running the app.
Implementation
Future<PlatformSummary> getPlatformSummary() {
throw UnimplementedError('getPlatformSummary() has not been implemented.');
}
Returns a summary of the Android platform running the app.
Future<PlatformSummary> getPlatformSummary() {
throw UnimplementedError('getPlatformSummary() has not been implemented.');
}