getSensors method
Returns the native Android sensors reported by the device.
Implementation
Future<List<NativeSensor>> getSensors() {
throw UnimplementedError('getSensors() has not been implemented.');
}
Returns the native Android sensors reported by the device.
Future<List<NativeSensor>> getSensors() {
throw UnimplementedError('getSensors() has not been implemented.');
}