getSystemFeatures method
Returns the native Android system features reported by the device.
Implementation
Future<List<SystemFeature>> getSystemFeatures() {
throw UnimplementedError('getSystemFeatures() has not been implemented.');
}
Returns the native Android system features reported by the device.
Future<List<SystemFeature>> getSystemFeatures() {
throw UnimplementedError('getSystemFeatures() has not been implemented.');
}