getThemeMode method
Returns the native system theme mode reported by the platform.
Implementation
Future<NativeLensThemeMode> getThemeMode() {
throw UnimplementedError('getThemeMode() has not been implemented.');
}
Returns the native system theme mode reported by the platform.
Future<NativeLensThemeMode> getThemeMode() {
throw UnimplementedError('getThemeMode() has not been implemented.');
}