watchPowerState method
Emits native battery and power state updates as the platform reports them.
Implementation
Stream<PowerState> watchPowerState() {
throw UnimplementedError('watchPowerState() has not been implemented.');
}
Emits native battery and power state updates as the platform reports them.
Stream<PowerState> watchPowerState() {
throw UnimplementedError('watchPowerState() has not been implemented.');
}