watchThemeMode method
Emits native system theme mode updates as the platform reports them.
Implementation
Stream<NativeLensThemeMode> watchThemeMode() {
throw UnimplementedError('watchThemeMode() has not been implemented.');
}
Emits native system theme mode updates as the platform reports them.
Stream<NativeLensThemeMode> watchThemeMode() {
throw UnimplementedError('watchThemeMode() has not been implemented.');
}