NativeLensScreenTrace class

A widget wrapper that prints screen debug information during development.

The debug output is emitted only when asserts are enabled. In release builds this widget simply returns its child without printing anything.

Inheritance

Constructors

NativeLensScreenTrace({Key? key, required String screenName, required String filePath, required String routeName, String? extra, required Widget child})
Creates a screen trace wrapper for debug builds.
const

Properties

child Widget
The widget below this wrapper in the tree.
final
extra String?
Optional extra context for the screen trace.
final
filePath String
The source file path for the current screen.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
routeName String
The route name associated with the current screen.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenName String
The display name of the current screen.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NativeLensScreenTrace>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited