NativeLensStreamProbeOptions class

Options for URL and manifest readiness probing before streaming playback.

Constructors

NativeLensStreamProbeOptions({Duration timeout = const Duration(seconds: 8), bool followRedirects = true, int maxRedirects = 5, int maxManifestBytes = 1024 * 1024, int extractSegmentLimit = 5, int extractVariantLimit = 10, bool requireHttps = false, List<String> allowedSchemes = const <String>['http', 'https'], Map<String, String> headers = const <String, String>{}})
Creates stream probe options.
const

Properties

allowedSchemes List<String>
URL schemes allowed by the probe.
final
extractSegmentLimit int
Maximum number of media segment URLs to extract from the manifest.
final
extractVariantLimit int
Maximum number of variant playlist URLs to extract from the manifest.
final
followRedirects bool
Whether HTTP redirects should be followed.
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
Optional HTTP headers to send with the probe request.
final
maxManifestBytes int
Maximum manifest response size to read, in bytes.
final
maxRedirects int
Maximum number of redirects to follow when redirects are enabled.
final
requireHttps bool
Whether the input and final stream URL must use HTTPS.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
Maximum time allowed for the probe request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited