isMasterPlaylist property
bool
get
isMasterPlaylist
Whether the manifest is classified as a master playlist.
Implementation
bool get isMasterPlaylist => hlsPlaylistType == 'master';
Whether the manifest is classified as a master playlist.
bool get isMasterPlaylist => hlsPlaylistType == 'master';