appEnvironment property
Safe app/device runtime environment hint, such as device or simulator.
Implementation
final String? appEnvironment;
Safe app/device runtime environment hint, such as device or simulator.
final String? appEnvironment;