isBatteryMonitoringEnabled property
Whether native battery monitoring is enabled for this reading.
Implementation
final bool? isBatteryMonitoringEnabled;
Whether native battery monitoring is enabled for this reading.
final bool? isBatteryMonitoringEnabled;