CompatibilitySummary class
A readable offline compatibility summary for a NativeLens report.
Constructors
-
CompatibilitySummary({required int overallScore, required String overallLevel, required String powerRiskLevel, required String networkRiskLevel, required String mediaCapabilityLevel, required String cameraCapabilityLevel, required String displayCapabilityLevel, required List<
String> recommendations, required List<String> warnings, required int generatedAtMillis}) -
Creates a compatibility summary from simple rule-based analysis.
const
Properties
- cameraCapabilityLevel → String
-
Readable camera capability level.
final
- displayCapabilityLevel → String
-
Readable display capability level.
final
- generatedAtMillis → int
-
The time this summary was generated, in milliseconds since epoch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mediaCapabilityLevel → String
-
Readable media capability level.
final
- networkRiskLevel → String
-
Readable network risk level.
final
- overallLevel → String
-
Readable overall level, such as Excellent, Good, Fair, or Limited.
final
- overallScore → int
-
Overall compatibility score from 0 to 100.
final
- powerRiskLevel → String
-
Readable power risk level.
final
-
recommendations
→ List<
String> -
Friendly suggestions based on the device capabilities.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
warnings
→ List<
String> -
Important limitations or runtime risks found in the report.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object> - Converts this compatibility summary to a map.
-
toString(
) → String -
Returns a readable string with all compatibility summary fields.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited