DeviceOrientationInfo class

Device orientation information reported by NativeLens.

Constructors

DeviceOrientationInfo({required String orientationName, required int rotationDegrees, required bool isPortrait, required bool isLandscape, required String source, required int timestampMillis})
Creates a device orientation snapshot or stream event.
const
DeviceOrientationInfo.fromMap(Map<Object?, Object?> map)
Creates a DeviceOrientationInfo instance from a platform channel map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isLandscape bool
Whether the orientation is classified as landscape.
final
isPortrait bool
Whether the orientation is classified as portrait.
final
orientationName String
The readable orientation name.
final
rotationDegrees int
The raw orientation rotation degrees if available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
The source of orientation data, such as display or orientation.
final
timestampMillis int
The timestamp when this orientation snapshot was produced.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object>
Converts this orientation information into a map for platform channel serialization.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited