DisplayInfo class
Native Android display information reported by the device.
Constructors
-
DisplayInfo({required int widthPixels, required int heightPixels, required double density, required int densityDpi, required double refreshRate, required List<
double> supportedRefreshRates, required bool isHdrSupported, required List<String> supportedHdrTypes}) -
Creates a display information description.
const
-
DisplayInfo.fromMap(Map<
Object?, Object?> map) -
Creates a DisplayInfo from a map returned by the native platform.
factory
Properties
- density → double
-
The logical display density scale.
final
- densityDpi → int
-
The display density in dots per inch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heightPixels → int
-
The display height in physical pixels.
final
- isHdrSupported → bool
-
Whether the active display reports HDR support.
final
- refreshRate → double
-
The current display refresh rate in hertz.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedHdrTypes
→ List<
String> -
Readable names for supported HDR types.
final
-
supportedRefreshRates
→ List<
double> -
Refresh rates supported by the active display, in hertz.
final
- widthPixels → int
-
The display width in physical pixels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object> - Converts this display information to a map using the native field names.
-
toString(
) → String -
Returns a readable string containing all display fields.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited