HlsVariantStream class
Metadata declared for an HLS master playlist variant stream.
Constructors
- HlsVariantStream({String? uri, String? url, int? bandwidth, int? averageBandwidth, int? width, int? height, String? codecs, double? frameRate, String? audioGroup, String? subtitlesGroup, String? closedCaptionsGroup, String? name})
-
Creates HLS variant stream metadata.
const
-
HlsVariantStream.fromMap(Map<
Object?, Object?> map) -
Creates variant metadata from a map using stable field names.
factory
Properties
- audioGroup → String?
-
Audio rendition group from the
AUDIOattribute.final - averageBandwidth → int?
-
Average segment bandwidth from the
AVERAGE-BANDWIDTHattribute.final - bandwidth → int?
-
Peak segment bandwidth from the
BANDWIDTHattribute.final - closedCaptionsGroup → String?
-
Closed captions rendition group from the
CLOSED-CAPTIONSattribute.final - codecs → String?
-
Codec list from the
CODECSattribute.final - frameRate → double?
-
Maximum frame rate from the
FRAME-RATEattribute.final - hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
Video height from the
RESOLUTIONattribute.final - name → String?
-
Optional variant name from the
NAMEattribute.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitlesGroup → String?
-
Subtitles rendition group from the
SUBTITLESattribute.final - uri → String?
-
Variant URI as declared in the master playlist.
final
- url → String?
-
Absolute variant URL resolved against the master playlist URL.
final
- width → int?
-
Video width from the
RESOLUTIONattribute.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Serializes variant metadata to a map using stable field names.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited