NativeLensDebug class
Utility helpers for debug-only screen trace printing in NativeLens.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
formatScreenTrace(
ScreenDebugInfo info) → String - Formats the screen debug trace into a readable multi-line string.
-
printScreen(
ScreenDebugInfo info) → void - Prints the screen debug trace only when assertions are enabled.