NativeLensFeatureOptions class
Optional intent modifiers for NativeLens feature intelligence.
Constructors
Properties
- disallowPowerSaveMode → bool
-
Whether the feature should avoid running while power saver is enabled.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highPerformance → bool
-
Whether the feature should prefer higher performance device conditions.
final
- minBatteryLevel → int?
-
Minimum battery percentage preferred for the feature.
final
- preferUnmeteredNetwork → bool
-
Whether the feature should prefer an unmetered active network.
final
- realtime → bool
-
Whether the feature is expected to run in realtime.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited