MethodChannelNativeLens class

An implementation of NativeLensPlatform that uses method channels.

Inheritance

Constructors

MethodChannelNativeLens()

Properties

deviceOrientationEventChannel EventChannel
The event channel used to receive live device orientation updates.
final
deviceOrientationStream Stream<DeviceOrientationInfo>
Emits device orientation updates as the device rotates.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
networkCapabilityEventChannel EventChannel
The event channel used to receive live Android network capability updates.
final
networkCapabilityStream Stream<NetworkCapability>
Emits native Android network capability updates as the active network changes.
no setteroverride
networkSpeedEventChannel EventChannel
The event channel used to receive live app network speed samples.
final
networkSpeedStream Stream<NetworkSpeedSample>
Emits app-level upload and download speed samples once per second.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCameraCapabilities() Future<List<CameraCapability>>
Returns native Android Camera2 capabilities reported by the device.
override
getDeviceOrientation() Future<DeviceOrientationInfo>
Returns the current device orientation from the Android display.
override
getDisplayInfo() Future<DisplayInfo>
Returns native Android display capabilities for the active display.
override
getMediaCodecs() Future<List<MediaCodecCapability>>
Returns native Android media codec capabilities reported by the device.
override
getNetworkCapability() Future<NetworkCapability>
Returns native Android network capability information for the active network.
override
getPlatformSummary() Future<PlatformSummary>
Returns a summary of the Android platform running the app.
override
getPowerState() Future<PowerState>
Returns native Android battery and power runtime state.
override
getSensors() Future<List<NativeSensor>>
Returns the native Android sensors reported by the device.
override
getSystemFeatures() Future<List<SystemFeature>>
Returns the native Android system features reported by the device.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited