NativeLensPlatform class abstract
The platform interface for NativeLens implementations.
- Inheritance
-
- Object
- PlatformInterface
- NativeLensPlatform
- Implementers
Constructors
- NativeLensPlatform()
- Constructs a NativeLensPlatform.
Properties
-
deviceOrientationStream
→ Stream<
DeviceOrientationInfo> -
Emits device orientation updates as the device rotates.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
networkCapabilityStream
→ Stream<
NetworkCapability> -
Emits native Android network capability updates as the active network changes.
no setter
-
networkSpeedStream
→ Stream<
NetworkSpeedSample> -
Emits app-level upload and download speed samples once per second.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCameraCapabilities(
) → Future< List< CameraCapability> > - Returns native Android Camera2 capabilities reported by the device.
-
getDeviceOrientation(
) → Future< DeviceOrientationInfo> - Returns the current device orientation from the Android display.
-
getDisplayInfo(
) → Future< DisplayInfo> - Returns native Android display capabilities for the active display.
-
getMediaCodecs(
) → Future< List< MediaCodecCapability> > - Returns native Android media codec capabilities reported by the device.
-
getNetworkCapability(
) → Future< NetworkCapability> - Returns native Android network capability information for the active network.
-
getPlatformSummary(
) → Future< PlatformSummary> - Returns a summary of the Android platform running the app.
-
getPowerState(
) → Future< PowerState> - Returns native Android battery and power runtime state.
-
getSensors(
) → Future< List< NativeSensor> > - Returns the native Android sensors reported by the device.
-
getSystemFeatures(
) → Future< List< SystemFeature> > - Returns the native Android system features reported by the device.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ NativeLensPlatform
-
The default instance of NativeLensPlatform to use.
getter/setter pair