networkCapabilityStream property

Stream<NetworkCapability> get networkCapabilityStream

Emits native network capability updates as the active network changes.

This stream listens to native network callbacks so active network changes can update the app without a manual refresh.

Implementation

Stream<NetworkCapability> get networkCapabilityStream {
  throw UnimplementedError(
    'networkCapabilityStream has not been implemented.',
  );
}