networkCapabilityStream property

Stream<NetworkCapability> get networkCapabilityStream

Emits native Android network capability updates as the active network changes.

This stream listens to Android network callbacks so Wi-Fi, mobile data, VPN, and flight mode changes can update the app without a manual refresh.

Implementation

Stream<NetworkCapability> get networkCapabilityStream {
  throw UnimplementedError(
    'networkCapabilityStream has not been implemented.',
  );
}