NativeLensReport class
A single snapshot report made from the existing NativeLens APIs.
Constructors
-
NativeLensReport({required PlatformSummary platformSummary, required List<
SystemFeature> systemFeatures, required List<NativeSensor> sensors, required DisplayInfo displayInfo, required List<MediaCodecCapability> mediaCodecs, required List<CameraCapability> cameraCapabilities, required PowerState powerState, required NetworkCapability networkCapability, required int generatedAtMillis}) -
Creates a complete NativeLens snapshot report.
const
Properties
-
cameraCapabilities
→ List<
CameraCapability> -
Native Android Camera2 capabilities reported by the device.
final
- displayInfo → DisplayInfo
-
Native Android display capabilities for the active display.
final
- generatedAtMillis → int
-
The time this report was generated, in milliseconds since epoch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mediaCodecs
→ List<
MediaCodecCapability> -
Native Android media codec capabilities reported by the device.
final
- networkCapability → NetworkCapability
-
Native Android network capability information for the active network.
final
- platformSummary → PlatformSummary
-
Basic Android build and device information.
final
- powerState → PowerState
-
Native Android battery and power runtime state.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sensors
→ List<
NativeSensor> -
Native Android sensors reported by the device.
final
-
systemFeatures
→ List<
SystemFeature> -
Native Android system features reported by the device.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Converts this report to a map using the public model field names.
-
toString(
) → String -
Returns a readable string with the report summary.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited