NativeLensTaskRequirements class
Developer-defined capability requirements for a custom NativeLens task.
Constructors
-
NativeLensTaskRequirements({bool requiresCamera = false, bool requiresMicrophone = false, bool requiresStableNetwork = false, bool requiresUnmeteredNetwork = false, bool requiresHevcEncoder = false, bool requiresMediaCodecs = false, List<
String> requiredSensors = const <String>[], List<String> requiredSystemFeatures = const <String>[], int? minBatteryLevel, double? minRefreshRate, int? minCameraCount, int? minSensorCount, int? minCodecCount, bool allowPowerSaveMode = true}) -
Creates custom task requirements.
const
-
NativeLensTaskRequirements.fromMap(Map<
Object?, Object?> map) -
Creates requirements from a map using stable field names.
factory
Properties
- allowPowerSaveMode → bool
-
Whether power saver mode is acceptable for the task.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- minBatteryLevel → int?
-
Minimum battery percentage required by the task.
final
- minCameraCount → int?
-
Minimum number of cameras required by the task.
final
- minCodecCount → int?
-
Minimum number of media codecs required by the task.
final
- minRefreshRate → double?
-
Minimum display refresh rate required by the task.
final
- minSensorCount → int?
-
Minimum number of sensors required by the task.
final
-
requiredSensors
→ List<
String> -
Sensor names or aliases required by the task.
final
-
requiredSystemFeatures
→ List<
String> -
Native system feature names required by the task.
final
- requiresCamera → bool
-
Whether at least one camera capability is required.
final
- requiresHevcEncoder → bool
-
Whether an HEVC encoder is required.
final
- requiresMediaCodecs → bool
-
Whether media codec capability is required.
final
- requiresMicrophone → bool
-
Whether microphone capability is required.
final
- requiresStableNetwork → bool
-
Whether a connected and validated network is required.
final
- requiresUnmeteredNetwork → bool
-
Whether the active network must be unmetered.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Serializes requirements to a map using stable field names.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited