NativeTaskRiskResult class
Offline risk analysis result for a NativeLens task.
Constructors
-
NativeTaskRiskResult({required NativeLensTask task, required String riskLevel, required double confidence, required List<
String> reasons, required String recommendation, required int analyzedAtMillis, List<String> requiredCapabilities = const <String>[], List<String> missingCapabilities = const <String>[], List<String> availableCapabilities = const <String>[]}) -
Creates a NativeLens task risk result.
const
Properties
- analyzedAtMillis → int
-
Analysis timestamp in milliseconds since epoch.
final
-
availableCapabilities
→ List<
String> -
Required or preferred capabilities currently available on the device.
final
- confidence → double
-
Confidence from 0.0 to 1.0.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
missingCapabilities
→ List<
String> -
Required or preferred capabilities that are unavailable or unstable.
final
-
reasons
→ List<
String> -
Human-readable reasons for the risk level.
final
- recommendation → String
-
Simple task-aware recommendation.
final
-
requiredCapabilities
→ List<
String> -
Capabilities required by the selected task.
final
- riskLevel → String
-
Current risk level. Expected values are
low,medium, andhigh.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- task → NativeLensTask
-
Task that was analyzed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object> - Serializes the result to a map using stable field names.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited