NetworkSpeedSample class
A live app-level network speed sample.
This measures this app's own Android UID traffic, not full device internet speed and not device-wide network usage.
Constructors
- NetworkSpeedSample({required int timestampMillis, required int rxBytesPerSecond, required int txBytesPerSecond, required double rxKbps, required double txKbps, required int totalRxBytes, required int totalTxBytes, required bool isSupported})
-
Creates a network speed sample.
const
-
NetworkSpeedSample.fromMap(Map<
Object?, Object?> map) -
Creates a NetworkSpeedSample from a map returned by the native platform.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSupported → bool
-
Whether Android supports UID traffic stats on this device.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- rxBytesPerSecond → int
-
Received bytes per second for this app.
final
- rxKbps → double
-
Received kilobits per second for this app.
final
- timestampMillis → int
-
The sample time in milliseconds since epoch.
final
- totalRxBytes → int
-
Total received bytes for this app UID.
final
- totalTxBytes → int
-
Total transmitted bytes for this app UID.
final
- txBytesPerSecond → int
-
Transmitted bytes per second for this app.
final
- txKbps → double
-
Transmitted kilobits per second for this app.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object> - Converts this speed sample to a map using the native field names.
-
toString(
) → String -
Returns a readable string containing all speed sample fields.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited