ScreenDebugInfo class

Information used by the NativeLens screen trace debug utility.

Constructors

ScreenDebugInfo({required String screenName, required String filePath, required String routeName, String? extra})
Creates screen debug information for NativeLensDebug and NativeLensScreenTrace.
const

Properties

extra String?
Optional extra context for the screen trace.
final
filePath String
The source file path for the current screen.
final
hashCode int
The hash code for this object.
no setterinherited
routeName String
The route name associated with the current screen.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenName String
The display name of the current screen.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, String?>
Converts this screen debug information into a map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited